@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "el2markdown" "0.0.8"
+(define-package "el2markdown" "20250105.1836"
   "Convert commentary of elisp files to markdown."
   ()
   :url "https://github.com/Lindydancer/el2markdown"
